@@ -166,7 +166,12 @@ class YNotebook(YBaseDoc):
             outputs = cell.get("outputs", [])
             for idx, output in enumerate(outputs):
                 if output.get("output_type") == "stream":
-                    output["text"] = Array(output.get("text", []))
+                    text = output.get("text", "")
+                    if isinstance(text, str):
+                        ytext = Text(text)
+                    else:
+                        ytext = Text("".join(text))
+                    output["text"] = ytext
                 outputs[idx] = Map(output)
             cell["outputs"] = Array(outputs)
             cell["execution_state"] = "idle"
@@ -197,7 +202,11 @@ class YNotebook(YBaseDoc):
         cells = []
         for i in range(len(self._ycells)):
             cell = self.get_cell(i)
-            if "id" in cell and meta["nbformat"] == 4 and meta["nbformat_minor"] <= 4:
+            if (
+                "id" in cell
+                and int(meta.get("nbformat", 0)) == 4
+                and int(meta.get("nbformat_minor", 0)) <= 4
+            ):
                 # strip cell IDs if we have notebook format 4.0-4.4
                 del cell["id"]
             if (
